@@ -3,8 +3,8 @@ mod chart;
 mod chart_data;
 mod chart_renderer;
 mod info_bar;
+mod volume_pane;
 mod y_axis;
 
 pub use chart::Candle;
-pub use chart::CandleType;
 pub use chart::Chart;
